searchData={"items":[{"type":"module","title":"JUnitFormatter","doc":"An `ExUnit.Formatter` implementation that generates a XML in the format understood by JUnit.\n\nTo accomplish this, there are some mappings that are not straight one to one.\nTherefore, here goes the mapping:\n\n- JUnit - `ExUnit`\n- Testsuites - :testsuite\n- Testsuite - `ExUnit.Case`\n- failures = failures\n- skipped = skipped\n- errors = invalid\n- time = (sum of all times in seconds rounded down)\n- Testcase - `ExUnit.Test`\n- name = :case\n- test = :test\n- content (only if not successful)\n- skipped = {:state, {:skipped, _}}\n- failed = {:state, {:failed, {_, reason, stacktrace}}}\n- reason = reason.message\n- content = `Exception.format_stacktrace/1`\n- error = {:invalid, module}\n\nThe report is written to a file in the `_build` directory.","ref":"JUnitFormatter.html"},{"type":"function","title":"JUnitFormatter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"JUnitFormatter.html#child_spec/1"},{"type":"function","title":"JUnitFormatter.format_time/1","doc":"Formats time from nanos to seconds","ref":"JUnitFormatter.html#format_time/1"},{"type":"function","title":"JUnitFormatter.get_report_file_path/0","doc":"Helper function to get the full path of the generated report file.\nIt can be passed 2 configurations\n- report_dir: full path of a directory (defaults to `Mix.Project.app_path()`)\n- report_file: name of the generated file (defaults to \"test-junit-report.xml\")","ref":"JUnitFormatter.html#get_report_file_path/0"},{"type":"module","title":"JUnitFormatter.Stats","doc":"A struct to keep track of test values and tests themselves.\n\nIt is used to build the testsuite JUnit node.","ref":"JUnitFormatter.Stats.html"},{"type":"type","title":"JUnitFormatter.Stats.t/0","doc":"","ref":"JUnitFormatter.Stats.html#t:t/0"},{"type":"extras","title":"Overview","doc":"JUnitFormatter\n=========\n\n\n[![Build Status](https://github.com/victorolinasc/junit-formatter/workflows/CI/badge.svg)](https://github.com/victorolinasc/junit-formatter/actions?query=workflow%3A%22CI%22) [![Hex Version](https://img.shields.io/hexpm/v/junit_formatter.svg)](http://hex.pm/packages/junit_formatter/) [![Documentation](https://img.shields.io/badge/docs-hexpm-blue.svg)](http://hexdocs.pm/junit_formatter/) [![Downloads](https://img.shields.io/hexpm/dt/junit_formatter.svg)](https://hex.pm/packages/junit_formatter) [![Coverage Status](https://coveralls.io/repos/github/victorolinasc/junit-formatter/badge.svg?branch=master)](https://coveralls.io/github/victorolinasc/junit-formatter?branch=master) [![Last Updated](https://img.shields.io/github/last-commit/victorolinasc/junit-formatter.svg)](https://github.com/victorolinasc/junit-formatter/commits/master)\n\nA simple ExUnit Formatter that collects test results and generates an XML report in JUnit format. This is intended to be used by tools that can produce a graphical report, mainly targeted at Jenkins and its support for JUnit.\n\nThe report is generated in `Mix.Project.app_path` folder with a default filename of `test-junit-report.xml`. It can be configured through application configuration on the key `report_file` (application `:junit_formatter`).\n\n> Versions 3+ require minimum Elixir version to be 1.5+. For older releases, please use version 2.2 of this library.","ref":"readme.html"},{"type":"extras","title":"Usage - Overview","doc":"First, add `JUnitFormatter` to the dependencies in your mix.exs:\n\n```elixir\n  defp deps do\n    [\n      {:junit_formatter, \"~> 3.4\", only: [:test]}\n    ]\n  end\n```\n\nNext, add `JUnitFormatter` to your `ExUnit` configuration in `test/test_helper.exs` file. It should look like this:\n\n\n```elixir\nExUnit.configure formatters: [JUnitFormatter]\nExUnit.start\n```\n\n\nIf you want to keep using the default formatter alongside the `JUnitFormatter` your `test/test_helper.exs` file should look like this:\n\n```elixir\nExUnit.configure formatters: [JUnitFormatter, ExUnit.CLIFormatter]\nExUnit.start\n```\n\nThen run your tests like normal:\n\n```\n....\n\nFinished in 0.1 seconds (0.07s on load, 0.08s on tests)\n4 tests, 0 failures\n\nRandomized with seed 600810\n```\n\nThe JUnit style XML report for this project looks like this:\n\n```xml\n<?xml version=\"1.0\"?>\n \n\t \n\t\t \n\t\t \n\t\t \n\t\t \n\t \n \n```\n\n*Note: This example has been reformatted for readability.*","ref":"readme.html#usage"},{"type":"extras","title":"Options - Overview","doc":"`JUnitFormatter` accepts 6 options that can be passed in config.exs (or equivalent environment configuration for tests):\n\n- `print_report_file` (boolean - default `false`): tells formatter if you want to see the path where the file is being written to in the console. This might help you debug where the file is. By default it writes the report to the `Mix.Project.app_path` folder. This ensures compatibility with umbrella apps.\n- `report_file` (binary - default `\"test-junit-report.xml\"`): the name of the file to write to. It must contain the extension. 99% of the time you will want the extension to be `.xml`, but if you don't you can pass any extension (though the contents of the file will be an XML document).\n- `report_dir` (binary - default `Mix.Project.app_path()`): the directory to which the formatter will write the report. Do not end it with a slash. **IMPORTANT!!** `JUnitFormatter` will **NOT**, by default, create the directory. If you are pointing to a directory that is outside _build then you can set the `automatic_create_dir?` option. \n- `prepend_project_name?` (boolean - default `false`): tells if the report file should have the name of the project as a prefix. See the \"Umbrella\" part of the documentation.\n- `use_project_subdirectory?` (boolean - default `false`): determines if the report file should be put into a subdirectory under `report_dir` named according to the project. If you set this then `automatic_create_dir?` will also be set to `true`. See the \"Umbrella\" part of the documentation.\n- `include_filename?` (boolean - default `false`): dictates whether ` `s in the XML report should include a \"file\" attribute of the relative path to the file of the test. Note that this defaults to false because not all JUnit ingesters will accept a file attribute.\n- `include_file_line?` (boolean - default `false`): only has effect when `include_filename?` is `true`. Dictates whether `file` attribute should include line of the test after a colon (e.g. `test/file_test.exs:123`).\n- `automatic_create_dir?` (boolean - default `false`): create a directory that defined in `report_dir` before writing report files.\n- `project_dir` (string - default `nil`). Specifies which directory the test file paths should be relative to within the XML. If unset or `nil`, the path to the test file is calculated relative to the current working directory.\n\nExample configuration:\n\n``` elixir\nconfig :junit_formatter,\n  report_file: \"report_file_test.xml\",\n  report_dir: \"/tmp\",\n  print_report_file: true,\n  prepend_project_name?: true,\n  include_filename?: true\n```\n\nThis would generate the report at: `/tmp/myapp-report_file_test.xml`.","ref":"readme.html#options"},{"type":"extras","title":"Umbrella projects - Overview","doc":"`JUnitFormatter` works with umbrella projects too. By default, it will generate the XML report on each sub-project build folder. So, as an example, if you have two apps (`my-app` and `another`) it will generate the following reports:\n\n- `_build/test/lib/my_app/report_file.xml`\n- `_build/test/lib/another/report_file.xml`\n\nThis works without any extra configuration. There are times, though, where you want to customize the directory where the reports are generated. Let's say you add this configuration:\n\n``` elixir\nconfig :junit_formatter,\n  report_dir: \"/tmp\"\n```\n\nThen, while running in an umbrella project, the first sub-project will run and generate a report file the following path:\n\n- `/tmp/report_file.xml`\n\nThe next one will do the same **OVERRIDING** the first one. So, in order to avoid this, you can use the configuration option `prepend_project_name?` so that the result would be:\n\n- `/tmp/my_app-report_file.xml`\n- `/tmp/another-report_file.xml`\n\nIf you want to use a consistent report filename, and instead place the reports under a subdirectory per application, then set the `use_project_subdirectory?` configuration flag to `true`. Using this configuration would result in the following file layout:\n\n- `/tmp/my_app/report_file.xml`\n- `/tmp/another/report_file.xml`\n\nIf you want to specify the paths to the test files in the report relative to the root of the umbrella project, not the individual application, then set `project_dir`. In your umbrella configuration file, at `config/test.exs`, if you set the following configuration:\n\n``` elixir\nconfig :junit_formatter,\n  project_dir: Path.expand(\"..\", __DIR__)\n```\n\nThen in your report, a test file within your umbrella at `apps/my_app/test/my_app_test.exs` will be specified within the report as `apps/my_app/test/my_app_test.exs`. If you leave `project_dir` unset it would instead be specified as `test/my_app_test.exs`.","ref":"readme.html#umbrella-projects"},{"type":"extras","title":"Integrating on CI systems - Overview","doc":"Most CIs have a way for uploading test reports. This is a nice way to understand what failed on your build. Most of them use the JUnit report file format to provide this feature.\n\n- [CircleCI](https://circleci.com/docs/2.0/language-elixir/) example configuration provides JUnit reports integration. For umbrella projects, if you set `use_project_subdirectory?: true` then CircleCI will provide reports per application. It is also advisable to set `project_dir` for umbrella projects so that files will be reported with their full path.","ref":"readme.html#integrating-on-ci-systems"},{"type":"extras","title":"LICENSE - Overview","doc":"This project is available under Apache Public License version 2.0. See [LICENSE](https://github.com/victorolinasc/junit-formatter/blob/master/LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [3.4.0] - 2024-04-02\n\n#","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- Minimum Elixir version bumped to 1.12 (because of sweet_xml minimum version)\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Test runs\n- Adjusted skipped test counting (#50 thanks to @mengdaming)\n\n## [3.3.1] - 2021-05-29\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"-  Don't store logs for test cases to reduce memory usage (#47 thanks to @vorce)\n\n## [3.3.0] - 2021-05-29\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Automatically creates report_dir (#44 thanks to @wingyplus)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Changelog","doc":"- Make it work with Elixir 1.12 (#45 thanks to @irgendeinich)\n\n## [3.2.0] - 2021-04-24\n\n#","ref":"changelog.html#fixes"},{"type":"extras","title":"Added - Changelog","doc":"- Option to include line number in reports. Fixes #40. (#41 thanks to @icehaunter)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Using `extra_applications` instead of `applications`\n- Switched CI system\n- Removed warnings in tests\n\n## [3.1.0] - 2020-03-14\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- If `include_filename?` attribute is true, add the relative path from … (#37 thanks to @danadaldos)\n\n## [3.0.1] - 2019-07-11\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Converts String to utf8 charlist, instead of Unicode (#34 thank to @mrmstn)","ref":"changelog.html#fixed"},{"type":"extras","title":"3.0.0 - Changelog","doc":"#","ref":"changelog.html#3-0-0"},{"type":"extras","title":"Breaking: - Changelog","doc":"- JUnitFormatter now supports only Elixir 1.5+. If you need support for older versions, please use version 2.x.\n\n#","ref":"changelog.html#breaking"},{"type":"extras","title":"Added: - Changelog","doc":"- Error messages now retain their whole format from standard ExUnit formatter (thanks to @hauleth)\n- Refactored the tests to use xpath (thanks to @hauleth)\n- Refactored the code base to be more modern (thanks to @hauleth)\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Bugfixes: - Changelog","doc":"- Fixed options description in README\n- Better CI integration: Credo, test tracing\n- Updated deps (and docs)","ref":"changelog.html#bugfixes"},{"type":"extras","title":"2.2.0 - Changelog","doc":"#","ref":"changelog.html#2-2-0"},{"type":"extras","title":"Bugfixes: - Changelog","doc":"- Fix Unicode characters in test names on OTP 20. It is important to notice that test names with Unicode characters that are not ASCII will **ONLY** work if running on OTP 20. Thanks to @sparta-developers\n  - Add option of prepending the project name to the report file to avoid overriding the results when in umbrella project. README was also updated. Thanks to @axelson for bringing the issue.","ref":"changelog.html#bugfixes"},{"type":"extras","title":"2.1.0 - Changelog","doc":"#","ref":"changelog.html#2-1-0"},{"type":"extras","title":"Bugfixes: - Changelog","doc":"- Fixes subprocess crashes. When a subprocess crashes it sends a {:EXIT, pid} message that can't be parsed by Atom.to_string/1. Thanks to @dmt !\n  - Fixes running tests on Elixir 1.6.0-rc.0. `ExUnit.Server.cases_loaded()` got renamed to `ExUnit.Server.modules_loaded()`.","ref":"changelog.html#bugfixes"},{"type":"extras","title":"2.0.0 - Changelog","doc":"#","ref":"changelog.html#2-0-0"},{"type":"extras","title":"Backwards incompatible: - Changelog","doc":"- This release raises the minimum Elixir version to 1.4. This is due to GenEvent handlers for ExUnit.Formatter being deprecated in Elixir 1.4.","ref":"changelog.html#backwards-incompatible"},{"type":"extras","title":"v1.3.0 - Changelog","doc":"#","ref":"changelog.html#v1-3-0"},{"type":"extras","title":"Bugfixes: - Changelog","doc":"- Handle errors that have a message with value `nil` properly. Thanks to @PierrePIRONIN.\n  - Fixed Elixir 1.4+ warnings. Thanks to @jwfearn.\n  - Improved test coverage (added skip tests).","ref":"changelog.html#bugfixes"},{"type":"extras","title":"v1.2.0 - Changelog","doc":"#","ref":"changelog.html#v1-2-0"},{"type":"extras","title":"Backwards incompatible: - Changelog","doc":"- This release raises the minimum Elixir version to 1.1 and is only tested with Erlang 18 and above.\n\n#","ref":"changelog.html#backwards-incompatible"},{"type":"extras","title":"Features: - Changelog","doc":"- Added config property `report_dir`. This makes it possible to set absolute paths for the generated reports.\n  - Added helper function `JUnitFormatter.get_report_file_path/0` that returns the final path of the report with the applied defaults and configurations.","ref":"changelog.html#features"},{"type":"extras","title":"v1.1.0 - Changelog","doc":"#","ref":"changelog.html#v1-1-0"},{"type":"extras","title":"Backwards incompatible: - Changelog","doc":"- This release has changed the location where the report is written to. \n\n#","ref":"changelog.html#backwards-incompatible"},{"type":"extras","title":"Features: - Changelog","doc":"- Changed implementation of logging report file location to use `Logger`. This is meant to be more helpful in configuring since it can be disabled in Logger level.\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Bugfixes: - Changelog","doc":"- Support for umbrella projects. Reports are written to `Mix.Project.app_path` instead of `Mix.Project.build_path`.","ref":"changelog.html#bugfixes"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"#","ref":"changelog.html#v1-0-0"},{"type":"extras","title":"Features: - Changelog","doc":"- `ExUnit.Formatter` implementation that prints an XML to the build directory.\n  \n#","ref":"changelog.html#features"},{"type":"extras","title":"Bugfixes: - Changelog","doc":"- Correctly show time of testsuite in seconds rather than micro seconds (thanks to [@ibizaman](https://github.com/ibizaman))\n  - Correctly handle errors with empty messages (thanks to [@Reimerei](https://github.com/Reimerei))\n  - Fixed name of failed tests tag in XML (thanks to [@KronicDeth](https://github.com/KronicDeth))\n  - Fixed compatibility with Elixir 1.2 (thanks to [@adrienmo](https://github.com/adrienmo))","ref":"changelog.html#bugfixes"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}